@@ -12,7 +12,7 @@ module ActiveSupport
   # * Limit the set of zones provided by TZInfo to a meaningful subset of 134
   #   zones.
   # * Retrieve and display zones with a friendlier name
-  #   (e.g., "Eastern \Time (US & Canada)" instead of "America/New_York").
+  #   (e.g., "Eastern Time (US & Canada)" instead of "America/New_York").
   # * Lazily load +TZInfo::Timezone+ instances only when they're needed.
   # * Create ActiveSupport::TimeWithZone instances via TimeZone's +local+,
   #   +parse+, +at+, and +now+ methods.
@@ -134,10 +134,10 @@ module ActiveSupport
       "Mumbai"                       => "Asia/Kolkata",
       "New Delhi"                    => "Asia/Kolkata",
       "Kathmandu"                    => "Asia/Kathmandu",
+      "Astana"                       => "Asia/Dhaka",
       "Dhaka"                        => "Asia/Dhaka",
       "Sri Jayawardenepura"          => "Asia/Colombo",
       "Almaty"                       => "Asia/Almaty",
-      "Astana"                       => "Asia/Almaty",
       "Novosibirsk"                  => "Asia/Novosibirsk",
       "Rangoon"                      => "Asia/Rangoon",
       "Bangkok"                      => "Asia/Bangkok",
@@ -208,7 +208,7 @@ module ActiveSupport
         TZInfo::Timezone.get(MAPPING[name] || name)
       end
 
-      alias_method :create, :new # :nodoc:
+      alias_method :create, :new
 
       # Returns a TimeZone instance with the given name, or +nil+ if no
       # such TimeZone instance exists. (This exists to support the use of
@@ -296,22 +296,15 @@ module ActiveSupport
     attr_reader :name
     attr_reader :tzinfo
 
-    ##
-    # :singleton-method: create
-    # :call-seq: create(name, utc_offset = nil, tzinfo = nil)
-    #
     # Create a new TimeZone object with the given name and offset. The
     # offset is the number of seconds that this time zone is offset from UTC
     # (GMT). Seconds were chosen as the offset unit because that is the unit
     # that Ruby uses to represent time zone offsets (see Time#utc_offset).
-
-    # :stopdoc:
     def initialize(name, utc_offset = nil, tzinfo = nil)
       @name = name
       @utc_offset = utc_offset
       @tzinfo = tzinfo || TimeZone.find_tzinfo(name)
     end
-    # :startdoc:
 
     # Returns the offset of this time zone from UTC in seconds.
     def utc_offset
@@ -355,7 +348,7 @@ module ActiveSupport
       "(GMT#{formatted_offset}) #{name}"
     end
 
-    # \Method for creating new ActiveSupport::TimeWithZone instance in time zone
+    # Method for creating new ActiveSupport::TimeWithZone instance in time zone
     # of +self+ from given values.
     #
     #   Time.zone = 'Hawaii'                    # => "Hawaii"
@@ -365,7 +358,7 @@ module ActiveSupport
       ActiveSupport::TimeWithZone.new(nil, self, time)
     end
 
-    # \Method for creating new ActiveSupport::TimeWithZone instance in time zone
+    # Method for creating new ActiveSupport::TimeWithZone instance in time zone
     # of +self+ from number of seconds since the Unix epoch.
     #
     #   Time.zone = 'Hawaii'        # => "Hawaii"
@@ -380,7 +373,7 @@ module ActiveSupport
       Time.at(*args).utc.in_time_zone(self)
     end
 
-    # \Method for creating new ActiveSupport::TimeWithZone instance in time zone
+    # Method for creating new ActiveSupport::TimeWithZone instance in time zone
     # of +self+ from an ISO 8601 string.
     #
     #   Time.zone = 'Hawaii'                     # => "Hawaii"
@@ -432,7 +425,7 @@ module ActiveSupport
       raise ArgumentError, "invalid date"
     end
 
-    # \Method for creating new ActiveSupport::TimeWithZone instance in time zone
+    # Method for creating new ActiveSupport::TimeWithZone instance in time zone
     # of +self+ from parsed string.
     #
     #   Time.zone = 'Hawaii'                   # => "Hawaii"
@@ -454,7 +447,7 @@ module ActiveSupport
       parts_to_time(Date._parse(str, false), now)
     end
 
-    # \Method for creating new ActiveSupport::TimeWithZone instance in time zone
+    # Method for creating new ActiveSupport::TimeWithZone instance in time zone
     # of +self+ from an RFC 3339 string.
     #
     #   Time.zone = 'Hawaii'                     # => "Hawaii"
@@ -552,11 +545,15 @@ module ActiveSupport
       tzinfo.local_to_utc(time, dst)
     end
 
-    def period_for_utc(time) # :nodoc:
+    # Available so that TimeZone instances respond like +TZInfo::Timezone+
+    # instances.
+    def period_for_utc(time)
       tzinfo.period_for_utc(time)
     end
 
-    def period_for_local(time, dst = true) # :nodoc:
+    # Available so that TimeZone instances respond like +TZInfo::Timezone+
+    # instances.
+    def period_for_local(time, dst = true)
       tzinfo.period_for_local(time, dst) { |periods| periods.last }
     end
 
@@ -564,14 +561,6 @@ module ActiveSupport
       tzinfo.periods_for_local(time)
     end
 
-    def abbr(time) # :nodoc:
-      tzinfo.abbr(time)
-    end
-
-    def dst?(time) # :nodoc:
-      tzinfo.dst?(time)
-    end
-
     def init_with(coder) # :nodoc:
       initialize(coder["name"])
     end
